(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9748,        354]*)
(*NotebookOutlinePosition[     10619,        384]*)
(*  CellTagsIndexPosition[     10575,        380]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Natural Numbers: Basic Definitions", "Theory Name"],

Cell[TextData[StyleBox["NN:Basic",
  FontSize->12,
  FontWeight->"Bold"]], "Theory Code"],

Cell["Florina Piroi", "Author"],

Cell["21.05.2005", "Date"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Description",
  FontSize->16]], "Description"],

Cell["A concise description of what this file contains.", "Text"]
}, Closed]],

Cell["", "Line",
  CellFrame->{{0, 0}, {0.25, 0}},
  CellMargins->{{Inherited, Inherited}, {3, 3}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellSize->{Inherited, 3.25}],

Cell[CellGroupData[{

Cell["The Peano Axioms", "Axioms"],

Cell["\<\
Informally, the Peano axioms may be stated as follows:

    * There is a natural number 0.
    * Every natural number a has a successor, denoted by S(a) or a'.
    * There is no natural number whose successor is 0.
    * Distinct natural numbers have distinct successors: a = b if and only if \
S(a) = S(b).
    * If a property is possessed by 0 and also by the successor of every \
natural number which possesses it, then it is possessed by all natural \
numbers. (This axiom, also known as axiom of induction, ensures that the \
proof technique of mathematical induction is valid.)\
\>", "Text"],

Cell[TextData[{
  "0 and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\^+\)\)]],
  " are given symbols."
}], "Text"],

Cell[BoxData[GridBox[{
        {\(\[ForAll] \+x\((\(x\^+\) \[NotEqual] 0)\)\)},
        {\(\[ForAll] \+\(x, y\)\((\((\(x\^+\) = \(y\^+\))\) \[Implies] \((x = 
                    y)\))\)\)},
        {\(\((P[
                  0] \[And] \((\[ForAll] \+x P[x] \[Implies] 
                    P[\(x\^+\)])\))\) \[Implies] \[ForAll] \+x P[x]\)}
        },
      ColumnAlignments->{Left}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of Addition", "Definitions"],

Cell["\<\
We define the addition '+' in terms of the successor operation\
\>", "Text"],

Cell[BoxData[GridBox[{
        {\(\[ForAll] \+m\((m + 0 = m)\)\)},
        {\(\[ForAll] \+\(m, n\)\((m + \(n\^+\) = \(\((m + n)\)\^+\))\)\)}
        },
      ColumnAlignments->{Left}]], "Input",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Propositions on Successor and Addition", "Propositions"],

Cell[CellGroupData[{

Cell["Successor", "Subsubsection"],

Cell[BoxData[GridBox[{
        {\(\[ForAll] \+x\((\(x\^+\) \[NotEqual] x)\)\)},
        {\(\[ForAll] \+x\((x \[NotEqual] \(x\^+\))\)\)}
        }]], "Input"],

Cell[BoxData[
    \(\[ForAll] \+x\((\((x \[NotEqual] 
              0)\) \[Implies] \[Exists] \+y\((x = \(y\^+\))\))\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Addition", "Subsubsection"],

Cell[BoxData[
    \(\[ForAll] \+n\((0 + n = n)\)\)], "Input",
  FontWeight->"Bold"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n\)\((\(m\^+\) + n = \(\((m + n)\)\^+\))\)\)], "Input",\

  FontWeight->"Bold"],

Cell["... further formulae (left out in this screenshot)...", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of Multiplication", "Definitions"],

Cell[BoxData[GridBox[{
        {\(\[ForAll] \+m\((m*0 = 0)\)\)},
        {\(\[ForAll] \+\(m, n\)\((m*\(n\^+\) = \((m*n)\) + m)\)\)}
        },
      ColumnAlignments->{Left}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Propositions on Multiplication", "Propositions"],

Cell[CellGroupData[{

Cell["Multiplication Only", "Subsubsection"],

Cell[BoxData[
    \(\[ForAll] \+n\((0*n = 0)\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n\)\((\(m\^+\)*n = \((m*n)\) + n)\)\)], "Input"],

Cell["1 is the neutral element for multiplication:", "Text"],

Cell[BoxData[
    \(\[ForAll] \+m\((\(0\^+\)*m = m)\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+m\((m*\(0\^+\) = m)\)\)], "Input"],

Cell["Comutativity", "Text"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n\)\((m*n = n*m)\)\)], "Input"],

Cell["Associativity", "Text"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n, p\)\((\((m*n)\)*p = m*\((n*p)\))\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n\)\((\((m*n = 
              0)\) \[Implies] \((\((m = 0)\) \[Or] \((n = 
                  0)\))\))\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Distributivity over Addition", "Subsubsection"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n, p\)\((\((m + n)\)*p = m*p + n*p)\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n, p\)\((m*\((n + p)\) = m*n + m*p)\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exponentiation: Definition and Properties", "Propositions"],

Cell[BoxData[
    RowBox[{"Definition", "[", 
      RowBox[{"\"\<Exponentiation\>\"", ",", GridBox[{
            {\(\[ForAll] \+m\((m\^0 := \(0\^+\))\)\)},
            {\(\[ForAll] \+\(m, n\)\((m\^\(n\^+\) := m\^n\ m)\)\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Propositions", "Subsubsection"],

Cell[TextData[{
  StyleBox["m",
    FontSlant->"Italic"],
  " exponent 1 is ",
  StyleBox["m",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(\[ForAll] \+m\((m\^\(0\^+\) = m)\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n, p\)\((m\^\(n + p\) = \(m\^n\) m\^p)\)\)], "Input"],

Cell["Multiply terms with the same exponent", "Text"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n, p\)\((m\^n*p\^n = \((m*p)\)\^n)\)\)], "Input"],

Cell["Multiply exponents", "Text"],

Cell[BoxData[
    \(\[ForAll] \+\(m, n, p\)\((m\^\(n*p\) = \((m\^n)\)\^p)\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Defining \[LessEqual] w.r.t successor, Properties\
\>", "Definitions"],

Cell[BoxData[
    RowBox[{"Definition", "[", 
      RowBox[{"\"\<succ and <=\>\"", ",", " ", GridBox[{
            {\(\[ForAll] \+x\((\((x \[LessEqual] 
                        0)\) \[DoubleLeftRightArrow] \((x = 0)\))\)\)},
            {\(\[ForAll] \+\(x, y\)\((\((x \[LessEqual] \(y\^+\))\) \
\[DoubleLeftRightArrow] \((\((x = \(y\^+\))\) \[Or] \((x \[LessEqual] 
                            y)\))\))\)\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["Properties of \[LessEqual] ", "Subsubsection"],

Cell[BoxData[
    \(\[ForAll] \+\(x, y\)\((\((\(x\^+\) \[LessEqual] 
              y)\) \[Implies] \((x \[LessEqual] y)\))\)\)], "Input",
  FontWeight->"Bold"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["predecessor and minus", "Definitions"],

Cell[BoxData[GridBox[{
        {\(\(0\^-\) := 0\)},
        {\(\[ForAll] \+m\((\(\(m\^+\)\^-\) := m)\)\)}
        },
      ColumnAlignments->{Left}]], "Input"],

Cell[BoxData[GridBox[{
        {\(\[ForAll] \+x\((x\[CircleMinus]0 = x)\)\)},
        {\(\[ForAll] \+\(x, y\)\((x\[CircleMinus]\(y\^+\) = \(\((x\
\[CircleMinus]y)\)\^-\))\)\)}
        },
      ColumnAlignments->{Left}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Propositions Involving predecessor and minus", "Propositions"],

Cell[BoxData[
    \(\[ForAll] \+\(x, y\)\((\(\((\(x\^+\)\[CircleMinus]y)\)\^-\) = \((x\
\[CircleMinus]y)\))\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+x\((\(\((\(x\^+\)\[CircleMinus]x)\)\^-\) = \((x\
\[CircleMinus]x)\))\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+x\((\(x\^+\)\[CircleMinus]x = \
\(\((x\[CircleMinus]x)\)\^+\))\)\)], "Input"],

Cell[BoxData[GridBox[{
        {\(\[ForAll] \+x\((0\[CircleMinus]x = 0)\)\)},
        {\(\[ForAll] \+\(x, y\)\((\((\(y\^+\)\[CircleMinus]\(x\^+\))\) = \((y\
\[CircleMinus]x)\))\)\)}
        },
      ColumnAlignments->{Left}]], "Input"],

Cell[BoxData[
    \(\[ForAll] \+x\((x\[CircleMinus]x = 0)\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+\(x, y\)\((\(\((x + 
                    y)\)\^+\)\[CircleMinus]x = \(y\^+\))\)\)], "Input"],

Cell[BoxData[
    \(\[ForAll] \+\(x, y\)\((\((x + y)\)\[CircleMinus]x = y)\)\)], "Input"],

Cell["There are no negative numbers! All are reduced to 0.", "Text"],

Cell[BoxData[
    \(\[ForAll] \+\(x, y\)\((x\[CircleMinus]\((x + y)\) = 0)\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1132, 902},
WindowMargins->{{3, Automatic}, {0, Automatic}},
Visible->True,
PrintingOptions->{"Magnification"->1.5},
ShowCellTags->True,
Magnification->1.5,
StyleDefinitions -> "TheoremaTheory.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 0, 141, "Theory Name"],
Cell[1836, 55, 89, 2, 60, "Theory Code"],
Cell[1928, 59, 31, 0, 38, "Author"],
Cell[1962, 61, 26, 0, 38, "Date"],

Cell[CellGroupData[{
Cell[2013, 65, 70, 1, 63, "Description"],
Cell[2086, 68, 65, 0, 70, "Text"]
}, Closed]],
Cell[2166, 71, 175, 4, 25, "Line"],

Cell[CellGroupData[{
Cell[2366, 79, 34, 0, 70, "Axioms"],
Cell[2403, 81, 607, 12, 229, "Text"],
Cell[3013, 95, 117, 5, 47, "Text"],
Cell[3133, 102, 394, 8, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3564, 115, 45, 0, 70, "Definitions"],
Cell[3612, 117, 86, 2, 47, "Text"],
Cell[3701, 121, 216, 5, 83, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3954, 131, 62, 0, 70, "Propositions"],

Cell[CellGroupData[{
Cell[4041, 135, 34, 0, 70, "Subsubsection"],
Cell[4078, 137, 157, 3, 70, "Input"],
Cell[4238, 142, 131, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4406, 149, 33, 0, 70, "Subsubsection"],
Cell[4442, 151, 83, 2, 70, "Input"],
Cell[4528, 155, 116, 3, 70, "Input"],
Cell[4647, 160, 69, 0, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4765, 166, 51, 0, 70, "Definitions"],
Cell[4819, 168, 185, 4, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5041, 177, 54, 0, 70, "Propositions"],

Cell[CellGroupData[{
Cell[5120, 181, 44, 0, 70, "Subsubsection"],
Cell[5167, 183, 59, 1, 70, "Input"],
Cell[5229, 186, 85, 1, 70, "Input"],
Cell[5317, 189, 60, 0, 70, "Text"],
Cell[5380, 191, 66, 1, 70, "Input"],
Cell[5449, 194, 66, 1, 70, "Input"],
Cell[5518, 197, 28, 0, 70, "Text"],
Cell[5549, 199, 68, 1, 70, "Input"],
Cell[5620, 202, 29, 0, 70, "Text"],
Cell[5652, 204, 87, 1, 70, "Input"],
Cell[5742, 207, 153, 3, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5932, 215, 53, 0, 70, "Subsubsection"],
Cell[5988, 217, 87, 1, 70, "Input"],
Cell[6078, 220, 87, 1, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6214, 227, 65, 0, 70, "Propositions"],
Cell[6282, 229, 293, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[6600, 239, 37, 0, 70, "Subsubsection"],
Cell[6640, 241, 131, 6, 70, "Text"],
Cell[6774, 249, 67, 1, 70, "Input"],
Cell[6844, 252, 90, 1, 70, "Input"],
Cell[6937, 255, 53, 0, 70, "Text"],
Cell[6993, 257, 86, 1, 70, "Input"],
Cell[7082, 260, 34, 0, 70, "Text"],
Cell[7119, 262, 88, 1, 54, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7256, 269, 80, 2, 70, "Definitions"],
Cell[7339, 273, 500, 10, 85, "Input"],

Cell[CellGroupData[{
Cell[7864, 287, 52, 0, 40, "Subsubsection"],
Cell[7919, 289, 159, 3, 54, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8127, 298, 44, 0, 70, "Definitions"],
Cell[8174, 300, 159, 4, 71, "Input"],
Cell[8336, 306, 229, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8602, 316, 68, 0, 70, "Propositions"],
Cell[8673, 318, 122, 2, 54, "Input"],
Cell[8798, 322, 115, 2, 51, "Input"],
Cell[8916, 326, 109, 2, 51, "Input"],
Cell[9028, 330, 235, 5, 85, "Input"],
Cell[9266, 337, 72, 1, 51, "Input"],
Cell[9341, 340, 124, 2, 54, "Input"],
Cell[9468, 344, 89, 1, 54, "Input"],
Cell[9560, 347, 68, 0, 47, "Text"],
Cell[9631, 349, 89, 1, 54, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

